@@ -14,15 +14,18 @@ from qhub.provider.oauth.auth0 import create_client
 from qhub.utils import (
     check_cloud_credentials,
     namestr_regex,
-    qhub_dask_version,
-    qhub_image_tag,
+    set_docker_image_tag,
     set_kubernetes_version,
+    set_qhub_dask_version,
 )
 
 from .version import __version__
 
 logger = logging.getLogger(__name__)
 
+qhub_image_tag = set_docker_image_tag()
+qhub_dask_version = set_qhub_dask_version()
+
 
 BASE_CONFIGURATION = {
     "project_name": None,
@@ -35,9 +38,9 @@ BASE_CONFIGURATION = {
         "authentication": None,
     },
     "default_images": {
-        "jupyterhub": f"quansight/qhub-jupyterhub:{qhub_image_tag}",
-        "jupyterlab": f"quansight/qhub-jupyterlab:{qhub_image_tag}",
-        "dask_worker": f"quansight/qhub-dask-worker:{qhub_image_tag}",
+        "jupyterhub": f"quay.io/nebari/nebari-jupyterhub:{qhub_image_tag}",
+        "jupyterlab": f"quay.io/nebari/nebari-jupyterlab:{qhub_image_tag}",
+        "dask_worker": f"quay.io/nebari/nebari-dask-worker:{qhub_image_tag}",
     },
     "storage": {"conda_store": "200Gi", "shared_filesystem": "200Gi"},
     "theme": {
@@ -116,6 +119,23 @@ LOCAL = {
     }
 }
 
+EXISTING = {
+    "node_selectors": {
+        "general": {
+            "key": "kubernetes.io/os",
+            "value": "linux",
+        },
+        "user": {
+            "key": "kubernetes.io/os",
+            "value": "linux",
+        },
+        "worker": {
+            "key": "kubernetes.io/os",
+            "value": "linux",
+        },
+    }
+}
+
 DIGITAL_OCEAN = {
     "region": "nyc3",
     "kubernetes_version": "PLACEHOLDER",
@@ -218,9 +238,12 @@ DEFAULT_ENVIRONMENTS = {
         "dependencies": [
             "python",
             "ipykernel",
-            "ipywidgets",
+            "ipywidgets==7.7.1",
             f"qhub-dask =={qhub_dask_version}",
             "python-graphviz",
+            "pyarrow",
+            "s3fs",
+            "gcsfs",
             "numpy",
             "numba",
             "pandas",
@@ -235,18 +258,18 @@ DEFAULT_ENVIRONMENTS = {
         "name": "dashboard",
         "channels": ["conda-forge"],
         "dependencies": [
-            "python==3.9.7",
-            "ipykernel==6.4.1",
-            "ipywidgets==7.6.5",
+            "python==3.9.13",
+            "ipykernel==6.15.1",
+            "ipywidgets==7.7.1",
             f"qhub-dask=={qhub_dask_version}",
-            "param==1.11.1",
-            "python-graphviz==0.17",
-            "matplotlib==3.4.3",
-            "panel==0.12.7",
-            "voila==0.3.5",
-            "streamlit==1.0.0",
-            "dash==2.0.0",
-            "cdsdashboards-singleuser==0.6.1",
+            "param==1.12.2",
+            "python-graphviz==0.20.1",
+            "matplotlib==3.3.2",
+            "panel==0.13.1",
+            "voila==0.3.6",
+            "streamlit==1.10.0",
+            "dash==2.6.1",
+            "cdsdashboards-singleuser==0.6.2",
         ],
     },
 }
@@ -387,6 +410,13 @@ def render_config(
         set_kubernetes_version(config, kubernetes_version, cloud_provider)
         if "AWS_DEFAULT_REGION" in os.environ:
             config["amazon_web_services"]["region"] = os.environ["AWS_DEFAULT_REGION"]
+
+    elif cloud_provider == "existing":
+        config["theme"]["jupyterhub"][
+            "hub_subtitle"
+        ] = "Autoscaling Compute Environment"
+        config["existing"] = EXISTING.copy()
+
     elif cloud_provider == "local":
         config["theme"]["jupyterhub"][
             "hub_subtitle"
